#[non_exhaustive]pub enum GridEditError {
OutOfBounds {
point: Point,
width: usize,
height: usize,
},
BlockedCell {
point: Point,
},
ZeroTraversalCost {
point: Point,
},
}Expand description
Error returned when a requested grid edit violates grid invariants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfBounds
Target cell lies outside 0..width × 0..height.
BlockedCell
Traversal cost cannot be set on a blocked cell.
ZeroTraversalCost
Traversal cost must be strictly positive.