pub trait SearchPathCost {
type Cost;
// Required method
fn path_cost(&self) -> Self::Cost;
}Expand description
Path value that exposes the cost reported by its search domain.
Cost units and optimality claims are defined by the owning lane (grid traversal cost, Euclidean polyline length, etc.).
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".