SearchPathCost

Trait SearchPathCost 

pub trait SearchPathCost {
    type Cost;

    // Required method
    fn path_cost(&self) -> Self::Cost;
}
Path value that exposes the cost reported by its search domain.

Cost units and optimality claims are defined by the owning lane (grid traversal cost, Euclidean polyline length, etc.).

Required Associated Types

type Cost

Cost type used by this path family (for example f64 Euclidean length).

Required Methods

fn path_cost(&self) -> Self::Cost

Returns the path’s domain-specific traversal cost.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors